@@ -713,3 +713,124 @@ class AtlasEventTypes(Enum):
     ORG_IDP_CERTIFICATE_CURRENT = 'Org Idp Certificate Current'
     SERVERLESS_DEPLOYMENT_CREATED = 'Serverless Deployment Created'
     SERVERLESS_DEPLOYMENT_DELETED = 'Serverless Deployment Deleted'
+    CLUSTER_INSTANCE_ADMIN_BACKUP_SNAPSHOT_REQUESTED = 'Cluster Instance Admin Backup Snapshot Requested'
+    ATLAS_ENVOY_SERVERLESS_LOGS = 'Atlas Envoy Serverless Logs'
+    ORG_LIMIT_UPDATED = 'Org Limit Updated'
+    ATLAS_DATA_LAKE_LOGS = 'Atlas Data Lake Logs'
+    PIT_LOGS = 'Pit Logs'
+    CPS_BACKUP_LOGS = 'Cps Backup Logs'
+    INSIDE_SERVERLESS_METRIC_THRESHOLD = 'Inside Serverless Metric Threshold'
+    OUTSIDE_SERVERLESS_METRIC_THRESHOLD = 'Outside Serverless Metric Threshold'
+    CLOUD_PROVIDER_THROTTLE_STATE_MODIFIED = 'Cloud Provider Throttle State Modified'
+    PROJECT_THROTTLE_STATE_MODIFIED = 'Project Throttle State Modified'
+    CLUSTER_THROTTLE_STATE_MODIFIED = 'Cluster Throttle State Modified'
+    FORCE_MIGRATE_FROM_AVAILABILITY_SETS = 'Force Migrate From Availability Sets'
+    TENANT_CLUSTER_LIMIT_MODIFIED = 'Tenant Cluster Limit Modified'
+    SERVERLESS_DEPLOYMENT_UPDATED = 'Serverless Deployment Updated'
+    INITIATE_SALESFORCE_SERVICE_CLOUD_SYNC = 'Initiate Salesforce Service Cloud Sync'
+    FTS_INDEX_CREATED = 'Fts Index Created'
+    FTS_INDEX_UPDATED = 'Fts Index Updated'
+    FTS_INDEX_DELETED = 'Fts Index Deleted'
+    INITIATE_SFDC_SYNC = 'Initiate Sfdc Sync'
+    SERVERLESS_DEPLOYMENT_INSTANCE_REPLACED = 'Serverless Deployment Instance Replaced'
+    AWS_BILLING_ACCOUNT_CREDIT_ISSUED = 'AWS Billing Account Credit Issued'
+    AWS_USAGE_REPORTED = 'AWS Usage Reported'
+    GCP_USAGE_REPORTED = 'GCP Usage Reported'
+    SERVERLESS_DEPLOYMENT_INSTANCE_REBOOTED = 'Serverless Deployment Instance Rebooted'
+    HOST_MONGOT_CRASHING_OOM_MTM = 'Host Mongot Crashing Oom MTM'
+    HOST_MONGOT_RECOVERED_OOM_MTM = 'Host Mongot Recovered Oom MTM'
+    SUPPORT_EMAILS_SENT_SUCCESSFULLY = 'Support Emails Sent Successfully'
+    PRIVATE_NETWORK_ENDPOINT_ENTRY_ADDED = 'Private Network Endpoint Entry Added'
+    PRIVATE_NETWORK_ENDPOINT_ENTRY_REMOVED = 'Private Network Endpoint Entry Removed'
+    PRIVATE_NETWORK_ENDPOINT_ENTRY_UPDATED = 'Private Network Endpoint Entry Updated'
+    CLUSTER_MONGOT_PROCESS_ARGS_UPDATE_SUBMITTED = 'Cluster Mongot Process Args Update Submitted'
+    CLUSTER_SERVER_PARAMETERS_UPDATE_SUBMITTED = 'Cluster Server Parameters Update Submitted'
+    M0_CLUSTERS_PER_GROUP_WITHIN_LIMIT = 'M0 Clusters Per Group Within Limit'
+    MAX_M0_CLUSTERS_PER_GROUP_EXCEEDED = 'Max M0 Clusters Per Group Exceeded'
+    CLUSTER_CONNECTION_CREATE_COLLECTION = 'Cluster Connection Create Collection'
+    AUTO_HEALING_ACTION = 'Auto Healing Action'
+    SUPPORT_EMAILS_SENT_FAILURE = 'Support Emails Sent Failure'
+    EXTRA_MAINTENANCE_DEFERRAL_GRANTED = 'Extra Maintenance Deferral Granted'
+    ADMIN_NOTE_UPDATED = 'Admin Note Updated'
+    ONLINE_ARCHIVE_RESUMED = 'Online Archive Resumed'
+    ONLINE_ARCHIVE_PAUSED_DUE_TO_FRS_JOB_ERRORS_CHECK = 'Online Archive Paused Due To Frs Job Errors Check'
+    ORG_ADMIN_LOCKED = 'Org Admin Locked'
+    REVOKED_EMPLOYEE_ACCESS_BYPASS = 'Revoked Employee Access Bypass'
+    HOST_ENOUGH_DISK_SPACE = 'Host Enough Disk Space'
+    HOST_NOT_ENOUGH_DISK_SPACE = 'Host Not Enough Disk Space'
+    AWS_SELF_SERVE_ACCOUNT_LINKED = 'AWS Self Serve Account Linked'
+    AWS_SELF_SERVE_ACCOUNT_LINK_PENDING = 'AWS Self Serve Account Link Pending'
+    AWS_SELF_SERVE_ACCOUNT_CANCELLED = 'AWS Self Serve Account Cancelled'
+    AWS_SELF_SERVE_ACCOUNT_LINK_FAILED = 'AWS Self Serve Account Link Failed'
+    OS_MAINTENANCE_RESTART = 'Os Maintenance Restart'
+    DEVICE_CODE_GENERATED = 'Device Code Generated'
+    SUCCESSFUL_DEVICE_CONFIRMATION_AUDIT = 'Successful Device Confirmation Audit'
+    GROUP_AUTOMATION_CONFIG_PUBLISHED = 'Group Automation Config Published'
+    CLUSTER_AUTOMATION_CONFIG_PUBLISHED = 'Cluster Automation Config Published'
+    ORG_CONNECTED_TO_VERCEL = 'Org Connected To Vercel'
+    DEVICE_CODE_CONFIRMED = 'Device Code Confirmed'
+    DEVICE_CODE_AUTHORIZED = 'Device Code Authorized'
+    UNLINKED_ORG = 'Unlinked Org'
+    ORG_UNLINKED_FROM_PAYING_ORG = 'Org Unlinked From Paying Org'
+    CLUSTER_LINKED_TO_VERCEL = 'Cluster Linked To Vercel'
+    DEVICE_REVOKED = 'Device Revoked'
+    ROLLING_INDEX_FAILED_INDEX_BUILD = 'Rolling Index Failed Index Build'
+    SCHEDULE_CREATED = 'Schedule Created'
+    SCHEDULE_DELETE_REQUESTED = 'Schedule Delete Requested'
+    SCHEDULE_PAUSE_REQUESTED = 'Schedule Pause Requested'
+    SCHEDULE_ENABLE_REQUESTED = 'Schedule Enable Requested'
+    SCHEDULE_UPDATE_REQUESTED = 'Schedule Update Requested'
+    SCHEDULE_MANUAL_TRIGGER_REQUESTED = 'Schedule Manual Trigger Requested'
+    SCHEDULE_RESUMED = 'Schedule Resumed'
+    SCHEDULE_SIDELINED = 'Schedule Sidelined'
+    DEVICE_REFRESHED = 'Device Refreshed'
+    TENANT_ENDPOINT_SERVICE_DEPLOYMENT_CREATED = 'Tenant Endpoint Service Deployment Created'
+    TENANT_ENDPOINT_SERVICE_CREATED = 'Tenant Endpoint Service Created'
+    TENANT_ENDPOINT_SERVICE_AVAILABLE = 'Tenant Endpoint Service Available'
+    TENANT_ENDPOINT_SERVICE_DEPLOYMENT_DELETE_REQUESTED = 'Tenant Endpoint Service Deployment Delete Requested'
+    TENANT_ENDPOINT_SERVICE_DELETED = 'Tenant Endpoint Service Deleted'
+    TENANT_ENDPOINT_SERVICE_DEPLOYMENT_DELETED = 'Tenant Endpoint Service Deployment Deleted'
+    TENANT_ENDPOINT_SERVICE_DEPLOYMENT_NUM_DESIRED_ENDPOINT_SERVICES_INCREASED = 'Tenant Endpoint Service Deployment Num Desired Endpoint Services Increased'
+    SERVERLESS_DEPLOYMENT_ENDPOINT_SERVICE_LINKED = 'Serverless Deployment Endpoint Service Linked'
+    SERVERLESS_DEPLOYMENT_ENDPOINT_SERVICE_UNLINKED = 'Serverless Deployment Endpoint Service Unlinked'
+    CLUSTER_CONNECTION_SAMPLE_COLLECTION_FIELD_NAMES = 'Cluster Connection Sample Collection Field Names'
+    ROLLING_INDEX_SUCCESS_INDEX_BUILD = 'Rolling Index Success Index Build'
+    ORG_CONNECTION_UNINSTALLED_FROM_VERCEL = 'Org Connection Uninstalled From Vercel'
+    SIGNING_KEY_ROTATION_TRIGGERED = 'Signing Key Rotation Triggered'
+    SIGNING_KEY_ROTATED = 'Signing Key Rotated'
+    GCP_SELF_SERVE_ACCOUNT_LINK_PENDING = 'GCP Self Serve Account Link Pending'
+    GCP_SELF_SERVE_ACCOUNT_LINK_FAILED = 'GCP Self Serve Account Link Failed'
+    QUOTA_USAGE_EXCEEDED_EVENT = 'Quota Usage Exceeded Event'
+    QUOTA_USAGE_WARNING_EVENT = 'Quota Usage Warning Event'
+    QUOTA_USAGE_CRITICAL_WARNING_EVENT = 'Quota Usage Critical Warning Event'
+    QUOTA_USAGE_CRITICAL_WARNING_PAGE_EVENT = 'Quota Usage Critical Warning Page Event'
+    PROJECT_OPERATIONAL_LIMIT_UPDATED = 'Project Operational Limit Updated'
+    GCP_SELF_SERVE_ACCOUNT_LINKED = 'GCP Self Serve Account Linked'
+    TENANT_ENDPOINT_CREATED = 'Tenant Endpoint Created'
+    TENANT_ENDPOINT_RESERVED = 'Tenant Endpoint Reserved'
+    TENANT_ENDPOINT_RESERVATION_FAILED = 'Tenant Endpoint Reservation Failed'
+    TENANT_ENDPOINT_UPDATED = 'Tenant Endpoint Updated'
+    TENANT_ENDPOINT_AVAILABLE = 'Tenant Endpoint Available'
+    TENANT_ENDPOINT_FAILED = 'Tenant Endpoint Failed'
+    TENANT_ENDPOINT_DELETING = 'Tenant Endpoint Deleting'
+    TENANT_ENDPOINT_DELETED = 'Tenant Endpoint Deleted'
+    ORG_DISCONNECTED_TO_VERCEL = 'Org Disconnected To Vercel'
+    ONLINE_ARCHIVE_DATA_EXPIRATION_RULE_ENABLED = 'Online Archive Data Expiration Rule Enabled'
+    ONLINE_ARCHIVE_DATA_EXPIRATION_RULE_UPDATED = 'Online Archive Data Expiration Rule Updated'
+    ONLINE_ARCHIVE_DATA_EXPIRATION_RULE_DISABLED = 'Online Archive Data Expiration Rule Disabled'
+    GCP_SELF_SERVE_ACCOUNT_CANCELLED = 'GCP Self Serve Account Cancelled'
+    INGESTION_PIPELINE_DELETED = 'Ingestion Pipeline Deleted'
+    OS_TUNE_FILE_OVERRIDES = 'Os Tune File Overrides'
+    BILLING_EMAIL_ADDRESS_ADDED = 'Billing Email Address Added'
+    BILLING_EMAIL_ADDRESS_CHANGED = 'Billing Email Address Changed'
+    BILLING_EMAIL_ADDRESS_REMOVED = 'Billing Email Address Removed'
+    INDEX_FAILED_INDEX_BUILD = 'Index Failed Index Build'
+    INDEX_SUCCESS_INDEX_BUILD = 'Index Success Index Build'
+    INGESTION_PIPELINE_CREATED = 'Ingestion Pipeline Created'
+    INGESTION_PIPELINE_UPDATED = 'Ingestion Pipeline Updated'
+    CLUSTER_PREFERRED_CPU_ARCHITECTURE_MODIFIED = 'Cluster Preferred Cpu Architecture Modified'
+    USER_ACCOUNT_EMAIL_ADDRESS_CHANGED_AUDIT = 'User Account Email Address Changed Audit'
+    ONLINE_ARCHIVE_DATA_EXPIRATION_DID_NOT_RUN = 'Online Archive Data Expiration Did Not Run'
+    ONLINE_ARCHIVE_DATA_EXPIRATION_RESOLVED = 'Online Archive Data Expiration Resolved'
+    LOG_FORWARDER_FAILURE = 'Log Forwarder Failure'
+    CLUSTER_UNLINKED_FROM_VERCEL = 'Cluster Unlinked From Vercel'
